==> haskell-websockets-0.12.7.3-148-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 websockets
version:              0.12.7.3
visibility:           public
id:                   websockets-0.12.7.3-6Kt6PgvqDYk3qW4eTBzKGi
key:                  websockets-0.12.7.3-6Kt6PgvqDYk3qW4eTBzKGi
license:              BSD-3-Clause
copyright:
    (c) 2010-2011 Siniša Biđin
    (c) 2011-2018 Jasper Van der Jeugt
    (c) 2011 Steffen Schuldenzucker
    (c) 2011 Alex Lang

maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:
    Siniša Biđin <sinisa@bidin.cc>
    Jasper Van der Jeugt <m@jaspervdj.be>
    Steffen Schuldenzucker <steffen.schuldenzucker@googlemail.com>
    Alex Lang <lang@tsurucapital.com>

stability:            experimental
homepage:             http://jaspervdj.be/websockets
synopsis:
    A sensible and clean way to write WebSocket-capable servers in Haskell.

description:
    This library allows you to write WebSocket-capable servers.

    An example server:
    <https://github.com/jaspervdj/websockets/blob/master/example/server.lhs>

    An example client:
    <https://github.com/jaspervdj/websockets/blob/master/example/client.hs>

    See also:

    * The specification of the WebSocket protocol:
    <http://www.whatwg.org/specs/web-socket-protocol/>

    * The JavaScript API for dealing with WebSockets:
    <http://www.w3.org/TR/websockets/>

category:             Network
abi:                  02db5f8aca36258fe4825a912cafbb87
exposed:              True
exposed-modules:
    Network.WebSockets Network.WebSockets.Client
    Network.WebSockets.Connection Network.WebSockets.Extensions
    Network.WebSockets.Stream

hidden-modules:
    Network.WebSockets.Connection.Options
    Network.WebSockets.Extensions.Description
    Network.WebSockets.Extensions.PermessageDeflate
    Network.WebSockets.Extensions.StrictUnicode Network.WebSockets.Http
    Network.WebSockets.Hybi13 Network.WebSockets.Hybi13.Demultiplex
    Network.WebSockets.Hybi13.Mask Network.WebSockets.Protocol
    Network.WebSockets.Server Network.WebSockets.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/websockets-0.12.7.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/websockets-0.12.7.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/websockets-0.12.7.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-websockets
hs-libraries:         HSwebsockets-0.12.7.3-6Kt6PgvqDYk3qW4eTBzKGi
depends:
    SHA-1.6.4.4-8ksu987L0xnDMFbhBLiacl
    async-2.2.5-D49NPDHTd69BKX3jfj3d2D
    attoparsec-0.14.4-Lk9m0Bu4xLu6fNaGof6SYp base-4.17.2.1
    base64-bytestring-1.2.1.0-IvMLrkp0izDH09fJ0OSCxo binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-CCVT39CBetAFHWteAF796d
    clock-0.8.4-EUlw1bAxERNJavBojz6iIc containers-0.6.7
    entropy-0.4.1.11-KgGl1Y7Pn5mDV1IyWdAGFR
    network-3.1.4.0-9GVXDAVmAL58RukaX2Kymu
    random-1.2.1.2-9A7wjy4kMRRA6JvDfUzvpH
    streaming-commons-0.2.3.0-CsWZYKlekn94JbnBRmYC9o text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-websockets/html/websockets.haddock
haddock-html:         /usr/share/doc/haskell-websockets/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-websockets-0.12.7.3-151-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 websockets
version:              0.12.7.3
visibility:           public
id:                   websockets-0.12.7.3-3PSPNlUqDfR7MvA3S6l2ic
key:                  websockets-0.12.7.3-3PSPNlUqDfR7MvA3S6l2ic
license:              BSD-3-Clause
copyright:
    (c) 2010-2011 Siniša Biđin
    (c) 2011-2018 Jasper Van der Jeugt
    (c) 2011 Steffen Schuldenzucker
    (c) 2011 Alex Lang

maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:
    Siniša Biđin <sinisa@bidin.cc>
    Jasper Van der Jeugt <m@jaspervdj.be>
    Steffen Schuldenzucker <steffen.schuldenzucker@googlemail.com>
    Alex Lang <lang@tsurucapital.com>

stability:            experimental
homepage:             http://jaspervdj.be/websockets
synopsis:
    A sensible and clean way to write WebSocket-capable servers in Haskell.

description:
    This library allows you to write WebSocket-capable servers.

    An example server:
    <https://github.com/jaspervdj/websockets/blob/master/example/server.lhs>

    An example client:
    <https://github.com/jaspervdj/websockets/blob/master/example/client.hs>

    See also:

    * The specification of the WebSocket protocol:
    <http://www.whatwg.org/specs/web-socket-protocol/>

    * The JavaScript API for dealing with WebSockets:
    <http://www.w3.org/TR/websockets/>

category:             Network
abi:                  0d5682689efdc3f25855f500eb04d504
exposed:              True
exposed-modules:
    Network.WebSockets Network.WebSockets.Client
    Network.WebSockets.Connection Network.WebSockets.Extensions
    Network.WebSockets.Stream

hidden-modules:
    Network.WebSockets.Connection.Options
    Network.WebSockets.Extensions.Description
    Network.WebSockets.Extensions.PermessageDeflate
    Network.WebSockets.Extensions.StrictUnicode Network.WebSockets.Http
    Network.WebSockets.Hybi13 Network.WebSockets.Hybi13.Demultiplex
    Network.WebSockets.Hybi13.Mask Network.WebSockets.Protocol
    Network.WebSockets.Server Network.WebSockets.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/websockets-0.12.7.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/websockets-0.12.7.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/websockets-0.12.7.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-websockets
hs-libraries:         HSwebsockets-0.12.7.3-3PSPNlUqDfR7MvA3S6l2ic
depends:
    SHA-1.6.4.4-8ksu987L0xnDMFbhBLiacl
    async-2.2.5-71qvS8UVmexLJ5VLFM0sV7
    attoparsec-0.14.4-2y9eL1gxaFn1uCSGoZSkZz base-4.17.2.1
    base64-bytestring-1.2.1.0-3bi2EtKyNEA1xONdADOQ95 binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-7gqgHDj4ifWAUMF7u0wWwn
    clock-0.8.4-1xdZcZlMdGT8MrV0CfarKe containers-0.6.7
    entropy-0.4.1.11-KgGl1Y7Pn5mDV1IyWdAGFR
    network-3.1.4.0-4jRwWQxmWDJ7j79sTkSj9R
    random-1.2.1.3-EDeqrsptr1q9TLFlKboGu1
    streaming-commons-0.2.3.0-1XHu7gUV9reHz4iwK8W2NW text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-websockets/html/websockets.haddock
haddock-html:         /usr/share/doc/haskell-websockets/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
